@@ -134,6 +134,7 @@ AudioFFmpegCodec = Literal[
 ]
 VideoCodec = Literal["H264", "H265", "VP8", "VP9", "AV1", "JPEG", "RAW"]
 VideoFFmpegCodec = Literal["h264", "hevc", "vp8", "vp9", "av1", "mjpeg", "rawvideo"]
+PythonVersion = Literal["3.9", "3.10", "3.11", "3.12"]
 
 
 # Interfaces as TypedDict
@@ -227,40 +228,65 @@ class PrebufferState(TypedDict, total=False):
     duration: int
 
 
+class RTPInfo(TypedDict):
+    payload: Optional[int]
+    codec: str
+    rate: Optional[int]
+    encoding: Optional[int]
+
+
+class FMTPInfo(TypedDict):
+    payload: int
+    config: str
+
+
 class AudioCodecProperties(TypedDict):
     sampleRate: int
     channels: int
     payloadType: int
+    fmtpInfo: Optional[FMTPInfo]
 
 
 class VideoCodecProperties(TypedDict):
     clockRate: int
     payloadType: int
+    fmtpInfo: Optional[FMTPInfo]
 
 
 class AudioStreamInfo(TypedDict):
     codec: AudioCodec
     ffmpegCodec: AudioFFmpegCodec
     properties: AudioCodecProperties
-    direction: Literal["sendonly", "recvonly"]
+    direction: Literal["sendonly", "recvonly", "sendrecv", "inactive"]
 
 
 class VideoStreamInfo(TypedDict):
     codec: VideoCodec
     ffmpegCodec: VideoFFmpegCodec
     properties: VideoCodecProperties
-    direction: Literal["sendonly"]
+    direction: Literal["sendonly", "recvonly", "sendrecv", "inactive"]
+
+
+class ProbeConfig(TypedDict, total=False):
+    video: VideoCodec
+    audio: AudioCodec
+    microphone: AudioCodec
 
 
 class ProbeStream(TypedDict):
     sdp: str
     audio: list[AudioStreamInfo]
-    video: VideoStreamInfo
+    video: list[VideoStreamInfo]
 
 
 class Go2RtcRTSPSource(TypedDict):
-    single: str
     default: str
+    defaultMicrophone: str
+    h264: str
+    h265: str
+    aac: str
+    opus: str
+    pcma: str
     mp4: str
 
 
@@ -549,7 +575,10 @@ class CameraDelegates(TypedDict):
     ptzDelegate: CameraPTZDelegate
 
 
-class CameraSource(Protocol):
+InternalSourceType = Literal["aac", "opus", "pcma"]
+
+
+class CameraBaseSource(Protocol):
     # from CameraInput
     id: str  # _id
     name: str
@@ -558,26 +587,43 @@ class CameraSource(Protocol):
     internal: bool
     # end CameraInput
 
+    async def probe_stream(
+        self, probe_config: Optional[ProbeConfig] = None, refresh: Optional[bool] = None
+    ) -> Optional[ProbeStream]: ...
+
+
+class CameraDeviceSource(CameraBaseSource, Protocol):
+    def get_internal_source(self, type: InternalSourceType) -> "CameraDeviceInternalSource": ...
     async def get_prebuffering_state(self, container: Container) -> Optional[PrebufferState]: ...
-    async def probe_stream(self, refresh: Optional[bool] = None) -> Optional[ProbeStream]: ...
 
 
-class CameraInternalSource(CameraSource, Protocol):
-    type: Literal["aac", "opus", "pcma"]
+class CameraDeviceInternalSource(CameraBaseSource, Protocol):
+    type: InternalSourceType
 
 
-class CameraDeviceSource(CameraSource, Protocol):
-    pass
-
-
-class CameraDeviceInternalSource(CameraInternalSource, CameraDeviceSource, Protocol):
-    pass
-
-
-class StreamingConnectionOptions(TypedDict, total=False):
+class WebRTCConnectionOptions(TypedDict, total=False):
     iceServers: list["IceServer"]
 
 
+class RTSPConnectionOptions(TypedDict, total=False):
+    target: Literal[
+        "default",
+        "defaultMicrophone",
+        "h264",
+        "h265",
+        "aac",
+        "opus",
+        "pcma",
+        "h264aac",
+        "h265aac",
+        "h264opus",
+        "h265opus",
+        "h264pcma",
+        "h265pcma",
+        "mp4",
+    ]
+
+
 SpawnInput = Union[str, int]
 
 
@@ -590,6 +636,11 @@ class FfmpegOptions(TypedDict):
     logger: Optional[dict[str, Any]]
 
 
+class ReturnAudioFFmpegOptions(TypedDict):
+    ffmpegPath: str
+    input: list[SpawnInput]
+
+
 class BaseCamera(TypedDict):
     _id: str
     nativeId: Optional[str]
@@ -730,7 +781,7 @@ class CameraDevice(Protocol):
     @property
     def stream_source(self) -> CameraDeviceSource: ...
     @property
-    def snapshot_source(self) -> Optional[CameraSource]: ...
+    def snapshot_source(self) -> Optional[CameraInput]: ...
     @property
     def high_resolution_source(self) -> Optional[CameraDeviceSource]: ...
     @property
